#!/bin/sh
# Script to clean up after the agent and MAPPs

# full paths to the pgms we need

TOUCH="/bin/touch"
RPM="/bin/rpm"
CHMOD="/bin/chmod"
RM="/bin/rm"
XARGS="/usr/bin/xargs"
EGREP="/bin/egrep"
GREP="/bin/grep"
PS="/bin/ps"
AWK="/bin/awk"
CCECLIENT="/usr/sausalito/bin/cceclient"

# files we need to remove

MD5LIST="/var/lib/cobalt/All-MgmtAgent-1.0-1.0.md5lst /var/lib/cobalt/All-MgmtAgent-1.1-1.1.md5lst"
HMDINITFILES="/etc/rc.d/init.d/hmd.init /etc/rc.d/rc0.d/K99hmd /etc/rc.d/rc3.d/S99hmd"

# make sure we aren't on a control station

if grep 4100CS /etc/build > /dev/null 2>&1 ; then 
   echo "ERROR: This script cannot be run on a control station. Exiting..."
   exit 1;
fi

# remove the pkg meta info associated with the agent

if [ -x "$CCECLIENT" ] ; then

   echo "INFO: Cleaning up entries from CCE..."

   for i in `echo 'find Package name=MgmtAgent' | "$CCECLIENT" 2>/dev/null | "$AWK" '$2 == "OBJECT" { print $3; }'` ;
   do
       echo "destroy $i" | "$CCECLIENT" > /dev/null 2>&1;
   done

else 
   # delete MD5 lists if found
   for i in $MD5LIST 
   do
      if [ -r "$i" ] ; then
         "$RM" -f "$i" 2> /dev/null && echo "INFO: Removed $i"
      fi
   done
fi

# rebuild the rpm db to make sure that --force installed pkgs don't have
# multiple counts

echo "INFO: Rebuilding RPM db..."

"$RPM" --rebuilddb

# make the HMD init files so that rpm -e goes smoothly

"$TOUCH" $HMDINITFILES
"$CHMOD" +x $HMDINITFILES

# remove the rpms

echo "INFO: Removing RPMS..."

 ( ( "$RPM" -qa | "$EGREP" 'base-mgmt|cobalt_agent|AppConfig|Time-modules' | "$XARGS" "$RPM" -e > /dev/null 2>&1 & ) ) &

# remove the HMD init files if they get left behind

"$RM" -f $HMDINITFILES

# kill the agent if its still running

"$PS" -auwxx | "$GREP" 'agent-' | "$GREP" -v grep | "$AWK" '{ print $2; }' | "$XARGS" kill -9 > /dev/null 2>&1

# Just do it - Phil says

echo "INFO: Removing remaining directories..."

"$RM" -rf /usr/mgmt

exit 0;
