#!/bin/sh
#
# getBuild.sh -> determine the "cobalt" style build number for
#                a system. Should work on most unix flavors

BUILD=
ETCBUILD="/etc/build"
AGENTBUILD="/usr/mgmt/etc/agent/build.txt"
TMPF="/var/tmp/getbuild.$$.`date +%Y%m%d%H%M%S.$$`"

# if we have /etc/build, parse it to get the build number

if [ -r "$ETCBUILD" ] ; then 
   awk '{ print $5 ; }' "$ETCBUILD" 2>/dev/null > "$TMPF" && \
   read BUILD < "$TMPF" && \
   /bin/rm -rf "$TMPF" ;
fi

# guess we don't have a /etc/build or we couldn't parse it

if [ "X$BUILD" = "X" ] ; then

   # try to figure out system type using prtdiag (this 
   # should work on sun4u and sun4d systems running a 
   # recent # version of Solaris such as 2.5.1 or newer)

   PRTDIAG="/usr/platform/`uname -i 2>/dev/null`/sbin/prtdiag"
   if [ -x "$PRTDIAG" ] ; then
      "$PRTDIAG" | \
      awk '/System Configuration:/ { print ; exit ; }' | \
      sed -e 's/^.*sun4[a-zA-Z] //' -e 's/^Sun //' \
          -e 's/ (.*$//' -e 's/ /\-/g' > "$TMPF" && \
      read BUILD < "$TMPF" && \
      /bin/rm -f "$TMPF" ; 
   fi

   # if prtdiag doesn't work, try uname -i

   if [ "X$BUILD" = "X" ] ; then
      uname -i 2> /dev/null | \
      sed -e 's/^SUNW,//' -e 's/ /\-/g' > "$TMPF" && \
      read BUILD < "$TMPF" && \
      /bin/rm -f "$TMPF" ;
   fi

   # if uname -i didn't work, try uname -sm

   if [ "X$BUILD"  = "X" ] ; then
      uname -sm 2> /dev/null | \
      sed -e 's/i[3-9]86/x86/' -e 's/ /\-/g' > "$TMPF" && \
      read BUILD < "$TMPF" && \
      /bin/rm -f "$TMPF" ; 
   fi

   # figure out the OS revision in major.minor format (we 
   # don't care about the extra stuff available in linux)

   uname -r 2> /dev/null | \
   awk -F. '{ printf ("%d.%d\n",$1,$2) ; }' > "$TMPF" && \
   read OSREV < "$TMPF" && \
   /bin/rm -f "$TMPF" ;

   if [ "X$BUILD" != "X" ] && [ "X$OSREV" != "X" ] ; then
      BUILD="0000$BUILD|$OSREV"
   fi
   
fi

# if we just can't figure it out say unknown

if [ "X$BUILD" = "X" ] ; then
   BUILD="0000Unknown"
fi

echo "$BUILD"

exit 0
